@@ -430,7 +430,7 @@ fn skip_leading_zeros_and_convert_to_bigints<F: PrimeField>(p: &Polynomial<F>) -
 
 fn convert_to_bigints<F: PrimeField>(p: &[F]) -> Vec<F::BigInteger> {
     let to_bigint_time = start_timer!(|| "Converting polynomial coeffs to bigints");
-    let coeffs = cfg_iter!(p).map(|s| s.into_repr()).collect::<Vec<_>>();
+    let coeffs = cfg_iter!(p).map(|s| s.to_repr()).collect::<Vec<_>>();
     end_timer!(to_bigint_time);
     coeffs
 }
